from setuptools import setup, find_packages

setup(
    name="cobertura-clover-transform",
    version='1.1b1',
    packages=find_packages(),
    description="Tools for transforming Cobertura test "
                "coverage XML into Clover-style XML",
    author='Chris Wacek',
    author_email='cwacek@gmail.com',
    url='http://github.com/cwacek/cobertura-clover-transform',
    license='MIT',
    keywords='cobertura coverage test clover xml'
)



import lxml.etree as ET
import argparse
import pkg_resources


def convert(inxml):

    dom = ET.parse(inxml)
    xslt = ET.parse(pkg_resources.resource_stream('cobertura_clover_transform',
                                                  'transform.xslt'))

    transform = ET.XSLT(xslt)
    newdom = transform(dom)
    return ET.tostring(newdom, pretty_print=True)


if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument('coverage_xml')
    parser.add_argument('-o', '--output', required=False)
    args = parser.parse_args()

    converted = convert(args.coverage_xml)

    if args.output:
        with open(args.output, 'w') as out:
            out.write(converted)
    else:
        print(converted)
